@@ -153,6 +153,7 @@ Version 0.4
 
 """
 
+import io
 import wx
 import math
 import zlib
@@ -166,9 +167,6 @@ try:
 except:
     pass
 
-# Python 2/3 compatibility helper
-import six
-
 # Built-in formats
 IntFormat = 1
 """ Integer format. """
@@ -225,7 +223,7 @@ def GetIndicatorBitmap():
 def GetIndicatorImage():
     """ Returns the image indicator as a :class:`wx.Image`. """
 
-    stream = six.BytesIO(GetIndicatorData())
+    stream = io.BytesIO(GetIndicatorData())
     return wx.Image(stream)
 
 
